==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-extension-computer-view/peony-extension-computer-view_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en_GB">
<context>
    <name>ComputerItemDelegate</name>
    <message>
        <location filename="computer-view/computer-item-delegate.cpp" line="142"/>
        <source>You should mount volume first</source>
        <translation>Primero debe montar el volumen</translation>
    </message>
</context>
<context>
    <name>ComputerNetworkItem</name>
    <message>
        <location filename="computer-view/computer-network-item.cpp" line="45"/>
        <source>Network Neighborhood</source>
        <translation>Vecindad de la red</translation>
    </message>
</context>
<context>
    <name>ComputerRemoteVolumeItem</name>
    <message>
        <location filename="computer-view/computer-remote-volume-item.cpp" line="84"/>
        <source>Remote</source>
        <translation>Remoto</translation>
    </message>
</context>
<context>
    <name>ComputerUserShareItem</name>
    <message>
        <source>User Share</source>
        <translation type="vanished">本机共享</translation>
    </message>
    <message>
        <location filename="computer-view/computer-user-share-item.cpp" line="20"/>
        <source>Data</source>
        <translation>Datos</translation>
    </message>
</context>
<context>
    <name>ComputerVolumeItem</name>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="54"/>
        <source>Volume</source>
        <translation>Volumen</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="63"/>
        <location filename="computer-view/computer-volume-item.cpp" line="115"/>
        <source>File System</source>
        <translation>Sistema de archivos</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="179"/>
        <source>Data</source>
        <translation>Datos</translation>
    </message>
</context>
<context>
    <name>LoginRemoteFilesystem</name>
    <message>
        <location filename="login-remote-filesystem.ui" line="41"/>
        <source>Connect to Sever</source>
        <translation>Conectar a Sever</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="89"/>
        <source>server information</source>
        <translation>Información del servidor</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="111"/>
        <source>user information</source>
        <translation>Información del usuario</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="141"/>
        <source>tag</source>
        <translation>etiqueta</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="196"/>
        <source>user</source>
        <translation>usuario</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="252"/>
        <source>password</source>
        <translation>contraseña</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="308"/>
        <source>protocol</source>
        <translation>protocolo</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="351"/>
        <source>server</source>
        <translation>servidor</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="382"/>
        <source>directory</source>
        <translation>directorio</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="411"/>
        <source>SAMBA</source>
        <translation></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="416"/>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="445"/>
        <source>/</source>
        <translation>/</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="476"/>
        <source>port</source>
        <translation>puerto</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="508"/>
        <source>20</source>
        <translation>20</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="513"/>
        <source>21</source>
        <translation>21</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="518"/>
        <source>137</source>
        <translation>137</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="523"/>
        <source>138</source>
        <translation>138</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="528"/>
        <source>139</source>
        <translation>139</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="533"/>
        <source>445</source>
        <translation>445</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="592"/>
        <source>ok</source>
        <translation>De acuerdo</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="623"/>
        <source>cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>Peony::ComputerViewContainer</name>
    <message>
        <location filename="computer-view-container.cpp" line="143"/>
        <source>Connect a server</source>
        <translation>Conectar un servidor</translation>
    </message>
    <message>
        <source>sftp://, etc...</source>
        <translation type="vanished">如sftp://...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">确定</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="171"/>
        <source>Unmount</source>
        <translation>Desmontar</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="185"/>
        <source>Eject</source>
        <translation>Expulsar</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="222"/>
        <location filename="computer-view-container.cpp" line="252"/>
        <source>format</source>
        <translation>formato</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="273"/>
        <location filename="computer-view-container.cpp" line="293"/>
        <source>Property</source>
        <translation>Propiedad</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="275"/>
        <source>You have to mount this volume first</source>
        <translation>Primero tienes que montar este volumen</translation>
    </message>
</context>
<context>
    <name>Peony::DriveRename</name>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="166"/>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="178"/>
        <source>Rename</source>
        <translation>Rebautizar</translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="178"/>
        <source>Device name:</source>
        <translation>Nombre del dispositivo:</translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="182"/>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="190"/>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="196"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="182"/>
        <source>Renaming cannot start with a decimal point, Please re-enter!</source>
        <translation>El cambio de nombre no puede comenzar con un punto decimal, ¡vuelva a ingresar!</translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="190"/>
        <source>The device name exceeds the character limit, rename failed!</source>
        <translation>El nombre del dispositivo supera el límite de caracteres, ¡error en el cambio de nombre!</translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="196"/>
        <source>Renaming will unmount the device. Do you want to continue?</source>
        <translation>Al cambiar el nombre, se desmontará el dispositivo. ¿Quieres continuar?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="peony-computer-view-plugin.h" line="42"/>
        <source>Computer View</source>
        <translation>Vista de computadora</translation>
    </message>
    <message>
        <location filename="peony-computer-view-plugin.h" line="43"/>
        <source>Show drives, network and personal directories</source>
        <oldsource>Show drives, network and personal directories.</oldsource>
        <translation>Mostrar unidades, redes y directorios personales</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="727"/>
        <source>One or more programs prevented the unmount operation.</source>
        <translation>Uno o más programas impedían la operación de desmontaje.</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="728"/>
        <location filename="computer-view/computer-volume-item.cpp" line="732"/>
        <location filename="computer-view/computer-volume-item.cpp" line="736"/>
        <source>Unmount failed</source>
        <translation>Error al desmontar</translation>
    </message>
    <message>
        <source>Error: %1
Do you want to unmount forcely?</source>
        <translation type="vanished">错误：%1
是否强制卸载？</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="321"/>
        <location filename="computer-view/computer-volume-item.cpp" line="389"/>
        <source>It need to synchronize before operating the device,place wait!</source>
        <translation>Es necesario sincronizarse antes de operar el dispositivo, ¡espere!</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="699"/>
        <source>The device has been mount successfully!</source>
        <translation>¡El dispositivo se ha montado con éxito!</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="720"/>
        <location filename="computer-view/computer-volume-item.cpp" line="755"/>
        <location filename="computer-view/computer-volume-item.cpp" line="796"/>
        <source>Data synchronization is complete,the device has been unmount successfully!</source>
        <translation>¡La sincronización de datos se ha completado, el dispositivo se ha desmontado correctamente!</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="728"/>
        <location filename="computer-view/computer-volume-item.cpp" line="736"/>
        <source>Error: %1
</source>
        <translation>Error: %1
</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="731"/>
        <source>Unable to unmount it, you may need to close some programs, such as: GParted etc.</source>
        <translation>Al no poder desmontarlo, es posible que deba cerrar algunos programas, como: GParted, etc.</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="732"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="764"/>
        <location filename="computer-view/computer-volume-item.cpp" line="790"/>
        <source>Eject device failed, the reason may be that the device has been removed, etc.</source>
        <translation>Error en el dispositivo de expulsión, la razón puede ser que el dispositivo se haya eliminado, etc.</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="766"/>
        <location filename="computer-view/computer-volume-item.cpp" line="792"/>
        <source>Eject failed</source>
        <translation>Error de expulsión</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>Eject Anyway</source>
        <translation type="vanished">无论如何弹出</translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="328"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="328"/>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation>Es posible que el dispositivo no admita la operación de cambio de nombre, ¡error en el cambio de nombre!</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="73"/>
        <source>Message recipient disconnected from message bus without replying!</source>
        <oldsource>Message recipient disconnected from message bus without replying</oldsource>
        <translation>¡El destinatario del mensaje se desconectó del bus de mensajes sin responder!</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="75"/>
        <source>log remote error</source>
        <translation>Error de registro remoto</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.20.0.0.orig.tar.gz: peony-extensions-4.20.0.0/peony-extension-computer-view/peony-extension-computer-view_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en_GB">
<context>
    <name>ComputerItemDelegate</name>
    <message>
        <location filename="computer-view/computer-item-delegate.cpp" line="142"/>
        <source>You should mount volume first</source>
        <translation>Primero debe montar el volumen</translation>
    </message>
</context>
<context>
    <name>ComputerNetworkItem</name>
    <message>
        <location filename="computer-view/computer-network-item.cpp" line="45"/>
        <source>Network Neighborhood</source>
        <translation>Vecindad de la red</translation>
    </message>
</context>
<context>
    <name>ComputerRemoteVolumeItem</name>
    <message>
        <location filename="computer-view/computer-remote-volume-item.cpp" line="84"/>
        <source>Remote</source>
        <translation>Remoto</translation>
    </message>
</context>
<context>
    <name>ComputerUserShareItem</name>
    <message>
        <source>User Share</source>
        <translation type="vanished">本机共享</translation>
    </message>
    <message>
        <location filename="computer-view/computer-user-share-item.cpp" line="40"/>
        <source>Data</source>
        <translation>Datos</translation>
    </message>
</context>
<context>
    <name>ComputerVolumeItem</name>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="54"/>
        <source>Volume</source>
        <translation>Volumen</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="63"/>
        <location filename="computer-view/computer-volume-item.cpp" line="115"/>
        <source>File System</source>
        <translation>Sistema de archivos</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="179"/>
        <source>Data</source>
        <translation>Datos</translation>
    </message>
</context>
<context>
    <name>Intel::ComputerItemDelegate</name>
    <message>
        <location filename="computer-view-intel/intel-computer-item-delegate.cpp" line="150"/>
        <source>You should mount volume first</source>
        <translation type="unfinished">Primero debe montar el volumen</translation>
    </message>
</context>
<context>
    <name>Intel::ComputerNetworkItem</name>
    <message>
        <location filename="computer-view-intel/intel-computer-network-item.cpp" line="47"/>
        <source>Network Neighborhood</source>
        <translation type="unfinished">Vecindad de la red</translation>
    </message>
</context>
<context>
    <name>Intel::ComputerRemoteVolumeItem</name>
    <message>
        <location filename="computer-view-intel/intel-computer-remote-volume-item.cpp" line="56"/>
        <source>Remote</source>
        <translation type="unfinished">Remoto</translation>
    </message>
</context>
<context>
    <name>Intel::ComputerViewContainer</name>
    <message>
        <location filename="computer-view-intel/intel-computer-view-container.cpp" line="105"/>
        <source>Connect a server</source>
        <translation type="unfinished">Conectar un servidor</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-view-container.cpp" line="139"/>
        <source>Unmount</source>
        <translation type="unfinished">Desmontar</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-view-container.cpp" line="145"/>
        <source>Eject</source>
        <translation type="unfinished">Expulsar</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-view-container.cpp" line="155"/>
        <location filename="computer-view-intel/intel-computer-view-container.cpp" line="171"/>
        <source>Property</source>
        <translation type="unfinished">Propiedad</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-view-container.cpp" line="157"/>
        <source>You have to mount this volume first</source>
        <translation type="unfinished">Primero tienes que montar este volumen</translation>
    </message>
</context>
<context>
    <name>Intel::ComputerVolumeItem</name>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="39"/>
        <source>Volume</source>
        <translation type="unfinished">Volumen</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="47"/>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="109"/>
        <source>System Disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="99"/>
        <source>User Disk</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginRemoteFilesystem</name>
    <message>
        <location filename="login-remote-filesystem.ui" line="41"/>
        <source>Connect to Sever</source>
        <translation>Conectar a Sever</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="89"/>
        <source>server information</source>
        <translation>Información del servidor</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="111"/>
        <source>user information</source>
        <translation>Información del usuario</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="141"/>
        <source>tag</source>
        <translation>etiqueta</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="196"/>
        <source>user</source>
        <translation>usuario</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="252"/>
        <source>password</source>
        <translation>contraseña</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="308"/>
        <source>protocol</source>
        <translation>protocolo</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="351"/>
        <source>server</source>
        <translation>servidor</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="382"/>
        <source>directory</source>
        <translation>directorio</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="411"/>
        <source>SAMBA</source>
        <translation></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="416"/>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="445"/>
        <source>/</source>
        <translation>/</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="476"/>
        <source>port</source>
        <translation>puerto</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="508"/>
        <source>20</source>
        <translation>20</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="513"/>
        <source>21</source>
        <translation>21</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="518"/>
        <source>137</source>
        <translation>137</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="523"/>
        <source>138</source>
        <translation>138</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="528"/>
        <source>139</source>
        <translation>139</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="533"/>
        <source>445</source>
        <translation>445</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="592"/>
        <source>ok</source>
        <translation>De acuerdo</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="623"/>
        <source>cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>Peony::ComputerViewContainer</name>
    <message>
        <location filename="computer-view-container.cpp" line="165"/>
        <source>Connect a server</source>
        <translation>Conectar un servidor</translation>
    </message>
    <message>
        <source>sftp://, etc...</source>
        <translation type="vanished">如sftp://...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">确定</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="193"/>
        <source>Unmount</source>
        <translation>Desmontar</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="207"/>
        <source>Eject</source>
        <translation>Expulsar</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="247"/>
        <location filename="computer-view-container.cpp" line="277"/>
        <location filename="computer-view-container.cpp" line="290"/>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="332"/>
        <source>Open In New Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="342"/>
        <source>Open In New Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>format</source>
        <translation type="vanished">formato</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="307"/>
        <location filename="computer-view-container.cpp" line="352"/>
        <source>Property</source>
        <translation>Propiedad</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="309"/>
        <source>You have to mount this volume first</source>
        <translation>Primero tienes que montar este volumen</translation>
    </message>
</context>
<context>
    <name>Peony::DriveRename</name>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="181"/>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="193"/>
        <source>Rename</source>
        <translation>Rebautizar</translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="193"/>
        <source>Device name:</source>
        <translation>Nombre del dispositivo:</translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="197"/>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="205"/>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="211"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="197"/>
        <source>Renaming cannot start with a decimal point, Please re-enter!</source>
        <translation>El cambio de nombre no puede comenzar con un punto decimal, ¡vuelva a ingresar!</translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="205"/>
        <source>The device name exceeds the character limit, rename failed!</source>
        <translation>El nombre del dispositivo supera el límite de caracteres, ¡error en el cambio de nombre!</translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="211"/>
        <source>Renaming will unmount the device. Do you want to continue?</source>
        <translation>Al cambiar el nombre, se desmontará el dispositivo. ¿Quieres continuar?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="peony-computer-view-plugin.h" line="42"/>
        <source>Computer View</source>
        <translation>Vista de computadora</translation>
    </message>
    <message>
        <location filename="peony-computer-view-plugin.h" line="43"/>
        <source>Show drives, network and personal directories</source>
        <oldsource>Show drives, network and personal directories.</oldsource>
        <translation>Mostrar unidades, redes y directorios personales</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="517"/>
        <location filename="computer-view/computer-volume-item.cpp" line="727"/>
        <source>One or more programs prevented the unmount operation.</source>
        <translation>Uno o más programas impedían la operación de desmontaje.</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="519"/>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="528"/>
        <location filename="computer-view/computer-volume-item.cpp" line="728"/>
        <location filename="computer-view/computer-volume-item.cpp" line="732"/>
        <location filename="computer-view/computer-volume-item.cpp" line="736"/>
        <source>Unmount failed</source>
        <translation>Error al desmontar</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="520"/>
        <source>Error: %1
Do you want to unmount forcely?</source>
        <translation>错误：%1
是否强制卸载？</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="321"/>
        <location filename="computer-view/computer-volume-item.cpp" line="389"/>
        <source>It need to synchronize before operating the device,place wait!</source>
        <translation>Es necesario sincronizarse antes de operar el dispositivo, ¡espere!</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="699"/>
        <source>The device has been mount successfully!</source>
        <translation>¡El dispositivo se ha montado con éxito!</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="720"/>
        <location filename="computer-view/computer-volume-item.cpp" line="755"/>
        <location filename="computer-view/computer-volume-item.cpp" line="796"/>
        <source>Data synchronization is complete,the device has been unmount successfully!</source>
        <translation>¡La sincronización de datos se ha completado, el dispositivo se ha desmontado correctamente!</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="728"/>
        <location filename="computer-view/computer-volume-item.cpp" line="736"/>
        <source>Error: %1
</source>
        <translation>Error: %1
</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="527"/>
        <location filename="computer-view/computer-volume-item.cpp" line="731"/>
        <source>Unable to unmount it, you may need to close some programs, such as: GParted etc.</source>
        <translation>Al no poder desmontarlo, es posible que deba cerrar algunos programas, como: GParted, etc.</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="529"/>
        <location filename="computer-view/computer-volume-item.cpp" line="732"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="764"/>
        <location filename="computer-view/computer-volume-item.cpp" line="790"/>
        <source>Eject device failed, the reason may be that the device has been removed, etc.</source>
        <translation>Error en el dispositivo de expulsión, la razón puede ser que el dispositivo se haya eliminado, etc.</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="553"/>
        <location filename="computer-view/computer-volume-item.cpp" line="766"/>
        <location filename="computer-view/computer-volume-item.cpp" line="792"/>
        <source>Eject failed</source>
        <translation>Error de expulsión</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="554"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="555"/>
        <source>Eject Anyway</source>
        <translation>无论如何弹出</translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="343"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="343"/>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation>Es posible que el dispositivo no admita la operación de cambio de nombre, ¡error en el cambio de nombre!</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="74"/>
        <source>Message recipient disconnected from message bus without replying!</source>
        <oldsource>Message recipient disconnected from message bus without replying</oldsource>
        <translation>¡El destinatario del mensaje se desconectó del bus de mensajes sin responder!</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="76"/>
        <location filename="computer-view-intel/intel-computer-view-container.cpp" line="59"/>
        <source>log remote error</source>
        <translation>Error de registro remoto</translation>
    </message>
</context>
</TS>
